"""
Bringing Leaflet maps to PyQt.
"""

__author__ = 'Leon Friedmann <leon.friedmann@tum.de>'
__version__ = '0.4.5'

from .mapwidget import MapWidget
from .leaflet import L
